@@ -79,7 +79,7 @@ static MagnifierOptions global_options = { ":0.0",
 					   500,
 					   50,
 					   0,
-					   1.0F,
+					   0.0F,
 					   0xFF000000,
 					   0,
 					   0,
@@ -316,7 +316,6 @@ magnifier_main_refresh_all (gpointer data)
 #ifdef DEBUG_REFRESH
 	fprintf (stderr, "refreshing %d regions\n", regions->_length);
 #endif
-#undef DEBUG_REFRESH
 
 	properties = GNOME_Magnifier_Magnifier_getProperties (BONOBO_OBJREF (magnifier), &ev);
 
@@ -328,10 +327,10 @@ magnifier_main_refresh_all (gpointer data)
 	}
 
 	dirty_bounds = (GNOME_Magnifier_RectBounds *) dirty_bounds_any->_value;
-	/*
+
 	  fprintf (stderr, "region to update: %d %d %d %d\n",
 		 dirty_bounds->x1, dirty_bounds->y1, dirty_bounds->x2, dirty_bounds->y2);
-	*/
+
 	for (i = 0; i < regions->_length; ++i)
 		GNOME_Magnifier_ZoomRegion_markDirty (
 			regions->_buffer [i], dirty_bounds, &ev);
@@ -394,7 +393,6 @@ main (int argc, char** argv)
   }
 
   magnifier = magnifier_new (global_options.is_override_redirect);
-  fprintf (stderr, "New magnifier created.\n");
   
   properties = GNOME_Magnifier_Magnifier_getProperties (
 	  BONOBO_OBJREF (magnifier), &ev);
@@ -416,9 +414,12 @@ main (int argc, char** argv)
 	  bonobo_pbclient_set_long (properties, "cursor-size",
 				    global_options.cursor_size, NULL);
 
-  else if (global_options.cursor_scale_factor != 1.0F)
+  else if (global_options.cursor_scale_factor != 0.0F)
 	  bonobo_pbclient_set_float (properties, "cursor-scale-factor",
 				     global_options.cursor_scale_factor, NULL);
+  else 
+	  bonobo_pbclient_set_float (properties, "cursor-scale-factor",
+				     global_options.zoom_factor, NULL);
 
   if (global_options.cursor_color)
 	  bonobo_pbclient_set_ulong (properties, "cursor-color",
@@ -471,7 +472,6 @@ main (int argc, char** argv)
   {
 	  int scroll_policy;
 	  
-	  fprintf (stderr, "Creating an initial zoom region.\n");
 	  init_rect_bounds (roi, 0, 0, 100, 100);
 	  init_rect_bounds (viewport, 0, 0, screen_width, screen_height);
 	  zoom_region =
