@@ -865,7 +865,7 @@ zoom_region_paint_crosswire_cursor (ZoomRegion *zoom_region, GdkRectangle *clip_
 	GdkColor color = {0, 0, 0, 0};
 	GdkColor tmp_color;
 	int x_left_clip = 0, x_right_clip = 0, y_top_clip = 0, y_bottom_clip = 0;
-	int csize;
+	int csize = 0;
 	
 #ifdef ZOOM_REGION_DEBUG
 	g_assert (zoom_region->alive);
@@ -927,10 +927,11 @@ zoom_region_paint_crosswire_cursor (ZoomRegion *zoom_region, GdkRectangle *clip_
 	if (clip_rect) gdk_gc_set_clip_rectangle (zoom_region->priv->crosswire_gc, clip_rect);
 	else gdk_gc_set_clip_rectangle (zoom_region->priv->crosswire_gc, NULL);
 
-	if (magnifier->crosswire_clip &&
-	    (cursor = magnifier_get_cursor (magnifier)))
-	{
+	if ((cursor = magnifier_get_cursor (magnifier))) {
 		gdk_drawable_get_size (cursor, &csize, &csize);
+	}
+	if (magnifier->crosswire_clip)
+	{
 		y_top_clip = rect.y - magnifier->cursor_hotspot.y -
 			magnifier->crosswire_size;
 		y_bottom_clip = rect.y +
@@ -941,6 +942,7 @@ zoom_region_paint_crosswire_cursor (ZoomRegion *zoom_region, GdkRectangle *clip_
 		x_right_clip = rect.x +
 			(csize - magnifier->cursor_hotspot.x) +
 			magnifier->crosswire_size;
+
 	}
 	if (magnifier->crosswire_size == 1)
 	{
@@ -1333,12 +1335,13 @@ zoom_region_calculate_scroll_rects (ZoomRegion *zoom_region,
 		DBG(fprintf (stderr, "deltas too big to scroll\n"));
 		retval = FALSE;
 	}
-	
-	scroll_rect->x = MAX (0, dx);
-	scroll_rect->y = MAX (0, dy);
-	scroll_rect->width = MIN (rect.width + dx, rect.width - dx);
-	scroll_rect->height = MIN (rect.height + dy, rect.height - dy);
-	
+	else {
+	    scroll_rect->x = MAX (0, dx);
+	    scroll_rect->y = MAX (0, dy);
+	    scroll_rect->width = MIN (rect.width + dx, rect.width - dx);
+	    scroll_rect->height = MIN (rect.height + dy, rect.height - dy);
+	}
+
 	expose_rect_h->x = 0;
 	expose_rect_h->y = (scroll_rect->y == 0) ? scroll_rect->height : 0;
 	expose_rect_h->width = rect.width;
